# ------------------------------------------------------------------------------
#
#                        THE ECONOMICS OF WOMEN'S RIGHTS  
#
# ------------------------------------------------------------------------------
#
# by Michèle Tertilt, Matthias Doepke, Anne Hannusch and Laura Montenbruck
#
# This version: 2022-11-22
#
# This file generates Figure 1 in the paper
#
# Inpute file : Overall_Index.txt in subdirectory '../output/figures/'
#               generated by 2_DataForFigures.do in subdirectory '../code/'
#
# Output files: WBLIndex_LnGDP_2000_JEEA.tex in subdirectory '../output/figures/'
#               WBLIndex_LnGDP_2000_JEEA.pdf in subdirectory ../'output/figures/'
#          
# Notes:
# - To run the code, please adjust working directory in line 43
#
# ------------------------------------------------------------------------------ 

 rm(list=ls())
  library(reshape2)
  library(scales)
  library(xtable) 
  library(base)
  library(ggplot2)
  library(grid)
  library(tikzDevice)
  library(tidyverse)
  library(lubridate)
  library(tidyr)
  library(magick)
  library(ggrepel)
 
  #---------------------------------------
  # Figure 1
  #---------------------------------------

  # Adjust working directory
  setwd("../ReplicationPackage/")
      
  law_indices <- read.table("output/figures/Overall_Index.txt", 
                            sep="\t",
                            header = TRUE)
  
  
  tikzDevice::tikz(file="output/figures/WBLIndex_LnGDP_2000_JEEA.tex",height=2.75, width=5.8)  
  
  Figure1 <- ggplot(data=law_indices, aes(x=wbl_index2000, y=log_gdp2000)) + 
    geom_point(data=subset(law_indices), size=1.75, color="#4040bf") +
    geom_smooth(method=lm, level = 0.9, color="#4040bf", size=0.75,  fill=c("#acace6")) +
    theme(panel.spacing = unit(0, "lines"), 
          strip.background = element_blank()) +
    theme_bw()+
    ylab("GDP per capita in 2000")+
    xlab("WBL Index in 2000")+
    scale_color_manual(values=c("#4040bf")) +  
    scale_y_continuous(breaks=c(0,log(1000),log(10000), log(100000)), labels=c("0","1,000","10,000","100,000"), limits=c(log(300), log(107000))) +
    theme(legend.position = "none",
          panel.border = element_blank(), panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"),
          axis.text.x = element_text(size=12, hjust=0.6),
          axis.text.y=element_text(size=12),
          axis.title.y=element_text(size=12,vjust=1.0),
          axis.title.x=element_text(size=12))
  
  ggsave("output/figures/WBLIndex_LnGDP_2000_JEEA.pdf", plot=Figure1,height=2.75, width=5.8)       
  
  print(Figure1)
  dev.off()   
   
  #-------------
  # end of file
  #-------------
  
