# ------------------------------------------------------------------------------
#
#                        THE ECONOMICS OF WOMEN'S RIGHTS  
#
# ------------------------------------------------------------------------------
#
# by Michèle Tertilt, Matthias Doepke, Anne Hannusch and Laura Montenbruck
#
# This version: 2022-11-22
#
# This file generates Figure 4 in the paper
#
# Inpute file : Overall_Index.txt in subdirectory '../output/figures/'
#               generated by 2_DataForFigures.do in subdirectory '../code/'
#
# Output files: WorldMap_1971_JEEA.pdf in subdirectory '../output/figures/'
#               WorldMap_1991_JEEA.pdf in subdirectory ../'output/figures/'
#               WorldMap_2017_JEEA.pdf in subdirectory ../'output/figures/'  
#
# Notes:
# - To run the code, please adjust working directory in line 40
#
# ------------------------------------------------------------------------------ 

rm(list=ls())
library(tidyverse)
library(ggthemes)
library(ggplot2)
library(readxl)
library(sf)
library(rnaturalearth)
library(rnaturalearthdata)
library(extrafont)

#---------------------------------------
# Figure 4
#---------------------------------------

# Adjust working directory
setwd("../ReplicationPackage/")

theme_set(theme_bw())

world <- ne_countries(scale = "medium", returnclass = "sf")
class(world)

law_indices <- read.table("output/figures/Overall_Index.txt", 
                          sep="\t",
                          header = TRUE)

data_merge <- merge(world, law_indices, by = c("iso_a3"))

idx_breaks <- c(20, 40, 60, 80, 100)

worldmap_1971 <- ggplot(data = data_merge) +
  geom_sf(aes(fill = combined_rights1971), size = 0.001) +
  scale_fill_viridis_c(breaks = idx_breaks, labels = idx_breaks, limits = c(19, 100),option = "plasma",direction = -1) +
  theme(legend.position = "bottom",
        legend.title = element_blank(),
        legend.text = element_text(size=9),
        legend.spacing.x = unit(0.25, 'cm'),
        legend.margin=margin(0,0,0,0),
        legend.box.margin=margin(-1,-1,-1,-1),
        panel.border = element_blank(), panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"), 
        axis.text.x = element_blank(),
        axis.text.y = element_blank(),
        axis.ticks = element_blank(),
        axis.line.x = element_blank(),
        axis.line.y = element_blank(),
        rect = element_blank()
  )

ggsave("output/figures/WorldMap_1971_JEEA.pdf",plot=worldmap_1971,height=4, width=7.5)    
 
print(worldmap_1971)
dev.off() 


worldmap_1991 <- ggplot(data = data_merge) +
  geom_sf(aes(fill = combined_rights1991), size = 0.001) +
  scale_fill_viridis_c(breaks = idx_breaks, labels = idx_breaks, limits = c(19, 100),option = "plasma",direction = -1) +
  theme(legend.position = "bottom",
        legend.title = element_blank(),
        legend.text = element_text(size=9),
        legend.spacing.x = unit(0.25, 'cm'),
        legend.margin=margin(0,0,0,0),
        legend.box.margin=margin(-1,-1,-1,-1),
        panel.border = element_blank(), panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"), 
        axis.text.x = element_blank(),
        axis.text.y = element_blank(),
        axis.ticks = element_blank(),
        axis.line.x = element_blank(),
        axis.line.y = element_blank(),
        rect = element_blank()
  )

ggsave("output/figures/WorldMap_1991_JEEA.pdf",plot=worldmap_1991,height=4, width=7.5) 

print(worldmap_1991)
dev.off() 

worldmap_2017 <- ggplot(data = data_merge) +
  geom_sf(aes(fill = combined_rights2017), size = 0.001) +
  scale_fill_viridis_c(breaks = idx_breaks, labels = idx_breaks, limits = c(19, 100),option = "plasma",direction = -1) +
  theme(legend.position = "bottom",
        legend.title = element_blank(),
        legend.text = element_text(size=9),
        legend.spacing.x = unit(0.25, 'cm'),
        legend.margin=margin(0,0,0,0),
        legend.box.margin=margin(-1,-1,-1,-1),
        panel.border = element_blank(), panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"), 
        axis.text.x = element_blank(),
        axis.text.y = element_blank(),
        axis.ticks = element_blank(),
        axis.line.x = element_blank(),
        axis.line.y = element_blank(),
        rect = element_blank()
  )

ggsave("output/figures/WorldMap_2017_JEEA.pdf",plot=worldmap_2017,height=4, width=7.5)    

#-------------
# end of file
#-------------
